<template>
  <div class="menu-wrapper">
    <template v-for="item in menu">
      <el-menu-item v-if="validatenull(item[childrenKey]) && vaildRoles(item)"
                    :key="item[labelKey]"
                    :class="{'is-active':vaildActive(item)}"
                    :index="item[pathKey]"
                    @click="open(item)">
        <div style="display: flex">
          <icon-show :name="item[iconKey]" class="iconShowSpan" :style="{ height: iconSize, width: iconSize }"></icon-show>
          <span slot="title"  style="margin-left: 8px;"
                :alt="item[pathKey]"
                :class="{'el-menu--display':collapse && first}">{{ generateTitle(item) }}</span>
        </div>
      </el-menu-item>
      <el-submenu v-else-if="!validatenull(item[childrenKey])&&vaildRoles(item)"
                  :key="item[labelKey]"
                  :index="item[pathKey]">
        <template slot="title">
          <div style="display: flex">
            <icon-show :name="item[iconKey]" class="iconShowSpan" :style="{ height: iconSize, width: iconSize }"></icon-show>
            <span slot="title"  style="margin-left: 8px;"
                  :class="{'el-menu--display':collapse && first}">{{ generateTitle(item) }}</span>
          </div>
        </template>
        <template v-for="(child,cindex) in item[childrenKey]">
          <el-menu-item v-if="validatenull(child[childrenKey])"
                        :key="child[labelKey]"
                        :class="{'is-active':vaildActive(child)}"
                        :index="child[pathKey],cindex"
                        @click="open(child)">
            <div style="display: flex">
              <icon-show :name="child[iconKey]" class="iconShowSpan" :style="{ height: iconSize, width: iconSize }"></icon-show>
              <span slot="title" style="margin-left: 8px;">{{ generateTitle(child) }}</span>
            </div>
          </el-menu-item>
          <sidebar-item v-else
                        :key="cindex"
                        :collapse="collapse"
                        :menu="[child]"
                        :props="props"
                        :screen="screen"></sidebar-item>
        </template>
      </el-submenu>
    </template>
  </div>
</template>
<script>
import {mapGetters} from "vuex";
import {isURL, validatenull} from "@/util/validate";
import config from "./config.js";

export default {
  name: "sidebarItem",
  data() {
    return {
      config: config
    };
  },
  props: {
    menu: {
      type: Array
    },
    screen: {
      type: Number
    },
    first: {
      type: Boolean,
      default: false
    },
    props: {
      type: Object,
      default: () => {
        return {};
      }
    },
    collapse: {
      type: Boolean
    }
  },
  created() {
  },
  mounted() {
  },
  computed: {
    ...mapGetters(["roles"]),
    iconSize() {
      return this.collapse ? '20px' : '16px';
    },
    labelKey() {
      return this.props.label || this.config.propsDefault.label;
    },
    pathKey() {
      return this.props.path || this.config.propsDefault.path;
    },
    iconKey() {
      return this.props.icon || this.config.propsDefault.icon;
    },
    childrenKey() {
      return this.props.children || this.config.propsDefault.children;
    },
    isOpenKey() {
      return this.props.isOpen || this.config.propsDefault.isOpen;
    },
    nowTagValue() {
      return this.$router.$avueRouter.getValue(this.$route);
    }
  },
  methods: {
    generateTitle(item) {
      return this.$router.$avueRouter.generateTitle(
        item[this.labelKey],
        (item.meta || {}).i18n
      );
    },
    vaildActive(item) {
      if (this.validIsOpen(item)) {
        return false;
      }
      const groupFlag = (item["group"] || []).some(ele =>
        this.$route.path.includes(ele)
      );
      return this.nowTagValue === item[this.pathKey] || groupFlag;
    },
    vaildRoles(item) {
      item.meta = item.meta || {};
      return item.meta.roles ? item.meta.roles.includes(this.roles) : true;
    },
    validatenull(val) {
      return validatenull(val);
    },
    validIsOpen(item) {
      if (item[this.isOpenKey] === 2 && isURL(item[this.pathKey])) {
        return true;
      }
    },
    open(item) {
      const query = {
        ...item.query,
        id:item.id,
        name:item.name
      }
      if (this.screen <= 1) this.$store.commit("SET_COLLAPSE");
      if (this.validIsOpen(item)) {
        window.open(item[this.pathKey]);
      } else {
        this.$router.$avueRouter.group = item.group;
        this.$router.$avueRouter.meta = item.meta;
        this.$router.push({
          path: this.$router.$avueRouter.getPath({
            name: item[this.labelKey],
            src: item[this.pathKey]
          }, item.meta),
          query: query
        });
      }
    }
  }
};
</script>
<style lang="scss" scoped>
.el-menu-item:focus, .el-menu-item:hover {
  outline: 0;
  background-color: #060708;
}
.iconShowSpan{
  display: inline-block;
  color: rgba(255, 255, 255, 0.7);
}
.el-menu-item .iconShowSpan,.el-submenu__title .iconShowSpan{
  margin-top: -2px;
}
.el-submenu__title:hover .iconShowSpan{
  color: #ffffff;
}
.el-submenu__title:hover .iconShowSpan svg{
  fill: #ffffff;
}
</style>


